# Get Started

基本的な使い方は以下の通りです。

1. magic-pocketをインストールします。
2. `pocket.toml`を作成します。
3. `pocket.toml`で指定したパスに、Dockerfileを作成します。
4. `settings.py`を修正します。
5. `pocket deploy`でデプロイします。

実際に動くサンプルを作るのが分かりやすいので、チュートリアルを参照してください。
